DataResponse

Enum DataResponse 

pub enum DataResponse<'a> {
    Capability(Vec<&'a str>),
    List {
        flags: Vec<&'a str>,
        delimiter: Option<&'a str>,
        name: &'a str,
    },
    Lsub {
        flags: Vec<&'a str>,
        delimiter: Option<&'a str>,
        name: &'a str,
    },
    Status {
        mailbox: &'a str,
        items: Vec<StatusItem>,
    },
    Search(Vec<u32>),
    Flags(Vec<&'a str>),
    Exists(u32),
    Recent(u32),
    Expunge(u32),
    Fetch {
        seq: u32,
        attributes: Vec<FetchAttribute<'a>>,
    },
    Other(&'a [u8]),
}
An untagged data response (* …).

Variants



Capability(Vec<&'a str>)

CAPABILITY — the server’s advertised capabilities.



List

LIST — a mailbox returned by the LIST command.

Fields

flags: Vec<&'a str>

Mailbox attribute flags (e.g. \Noselect, \HasChildren).

delimiter: Option<&'a str>

Hierarchy delimiter, or None for a flat namespace (NIL).

name: &'a str

The mailbox name.



Lsub

LSUB — a subscribed mailbox returned by the LSUB command.

Fields

flags: Vec<&'a str>

Mailbox attribute flags.

delimiter: Option<&'a str>

Hierarchy delimiter, or None (NIL).

name: &'a str

The mailbox name.



Status

STATUS — requested status attributes for a mailbox.

Fields

mailbox: &'a str

The mailbox the status items describe.

items: Vec<StatusItem>

The returned status items.



Search(Vec<u32>)

SEARCH — message numbers (or UIDs) matching a search.



Flags(Vec<&'a str>)

FLAGS — the flags defined in the selected mailbox.



Exists(u32)

EXISTS — the number of messages in the mailbox.



Recent(u32)

RECENT — the number of messages with the \Recent flag.



Expunge(u32)

EXPUNGE — the sequence number of a message that was expunged.



Fetch

FETCH — message data for a single message.

Fields

seq: u32

The message sequence number.

attributes: Vec<FetchAttribute<'a>>

The fetched attributes for this message.



Other(&'a [u8])

Unrecognized untagged data response — the raw line bytes (without CRLF).